@@ -3,8 +3,8 @@ Soft Potato pip version
 
 """
 
-import tech
-import calc
+import .tech
+import .calc
 
 
 __version__ = "0.7"
